@@ -1,8 +1,8 @@
 ###      Methods for the class of random-effects structures.
 ###
+### Copyright 2006-2019 The R Core team
 ### Copyright 1997-2003  Jose C. Pinheiro,
 ###                      Douglas M. Bates <bates@stat.wisc.edu>
-# Copyright 2006-2012 The R Core team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -277,38 +277,32 @@ Initialize.reStruct <-
   MEEM(object, conLin, control$niterEM) # refine initial estimates with EM
 }
 
-logDet.reStruct <-
-  function(object, ...)
-{
-  unlist(lapply(object, logDet))
-}
+logDet.reStruct <- function(object, ...)  vapply(object, logDet, numeric(1))
 
-logLik.reStruct <-
-  function(object, conLin, ...)
+logLik.reStruct <- function(object, conLin, ...)
 {
   if(any(!is.finite(conLin$Xy))) return(-Inf)
   ## 17-11-2015; Fixed sigma patch; SH Heisterkamp; Quantitative Solutions
   dims <- conLin$dims
-  REML <- as.integer(attr(object, "settings"))[1]
+  settings <- as.integer(attr(object, "settings"))
+  REML <- settings[1]
   val <- .C(mixed_loglik,
      as.double(conLin$Xy),
      as.integer(unlist(conLin$dims)),
      as.double(pdFactor(object)),
-     as.integer(attr(object, "settings")),
+     settings,
      loglik = double(1),
      lRSS = double(1),
      as.double(conLin$sigma))
 
   if (conLin$sigma > 0 && REML == 1) {
-     nc <- dims$ncol
-     p <- nc[dims$Q + 1]
+     ## nc <- dims$ncol; p <- nc[dims$Q + 1]
      N <- dims$N
      aux <- N * log(conLin$sigma) - exp(val[["lRSS"]]) /  (2*conLin$sigma)
      val[["loglik"]] + aux
   } else {
      val[["loglik"]]
   }
-  ########
 }
 
 "matrix<-.reStruct" <-
@@ -363,18 +357,17 @@ model.matrix.reStruct <-
                      length(levels(x)) > 1) contrasts(x) else NULL ))
   contr[names(contrast)] <- contrast
 
-  ncols <- as.vector(unlist(lapply(value, length)))
+  ncols <- lengths(value)
   nams <- if (length(value) == 1) {
     names(value[[1]])
   } else {
     paste(rep(names(value), ncols), unlist(lapply(value, names)), sep = ".")
   }
-  val <- matrix(unlist(value), nrow = nrow(data),
-                dimnames = list(row.names(data), nams))
-  attr(val, "ncols") <- ncols
-  attr(val, "nams") <- as.list(lapply(value, names))
-  attr(val, "contr") <- contr
-  val
+  structure(matrix(unlist(value), nrow = nrow(data),
+		   dimnames = list(row.names(data), nams)),
+	    ncols = ncols,
+	    nams = lapply(value, names),
+	    contr = contr)
 }
 
 Names.reStruct <-
