@@ -138,7 +138,7 @@ stopifnot(
               c(lKe = 0.0640155, lKa = 0.196058, lCl = 0.0808379), tol = 5e-5)
     ,
     all.equal(aM4[,"F-value"],
-              c(65.439, 9.09557, 1581.21), tol = 5e-5)
+              c(65.439, 9.09557, 1581.21), tol = 1e-4) # ATLAS had 7.86e-05
 )
 
 ##
